pub struct SecureKey { /* private fields */ }Expand description
Wrapper around a SecureArray<u8, 32> that holds the private key
Implementations
Sourceimpl SecureKey
impl SecureKey
Sourcepub fn key(&self) -> SecureArray<u8, 32>
pub fn key(&self) -> SecureArray<u8, 32>
Return the private key by cloning it
Sourcepub fn key_string(&self) -> SecureString
pub fn key_string(&self) -> SecureString
Return the key in a SecureString
pub fn is_erased(&self) -> bool
pub fn address(&self) -> Address
Sourcepub fn to_signer(&self) -> PrivateKeySigner
pub fn to_signer(&self) -> PrivateKeySigner
Converts the private key to a PrivateKeySigner by cloning the inner key
Panics
Panics if the key is not a valid form of a private key or if it has been erased
Sourcepub fn to_signing_key(&self) -> SigningKey
pub fn to_signing_key(&self) -> SigningKey
Converts the private key to a SigningKey by cloning the inner key
Panics
Panics if the key is not a valid form of a private key or if it has been erased
Sourcepub fn to_wallet(&self) -> EthereumWallet
pub fn to_wallet(&self) -> EthereumWallet
Converts the private key to an EthereumWallet by cloning the inner key
Panics
Panics if the key is not a valid form of a private key or if it has been erased
Sourcepub fn verifying_key(&self) -> VerifyingKey
pub fn verifying_key(&self) -> VerifyingKey
Converts the private key to a VerifyingKey by cloning the inner key
Panics
Panics if the key is not a valid form of a private key or if it has been erased